<?php
	/**
	 * class CEditor
	*@author Adam Heinrich
	* <a.heinrich@seznam.cz>
	*/
	class CEditor {
		private $img; // image resource
		private $conf = Array('linespace' => 5, // spaces between lines
											'linestart' => 0, // where stave starts
											'width' => 100, // stave width
											'imgpath' => 'img/' // path to images directory
											);
		
		public function __construct($img, $conf) {
			$this->img = $img;
			$this->conf = $conf;
		}
		
		/**
          * hexRGB
           * returns color components (red, green and blue) in associative array
           * @returns array ('red', 'green', 'blue')
           */
        private function hexRGB ($hexstr) {
            $int = hexdec($hexstr);
            return array('red' => 0xFF & ($int >> 0x10), 'green' => 0xFF & ($int >> 0x8), 'blue' => 0xFF & $int);
        }

		/**
		 * DrawStave
		 */
		public function DrawBackground() {
			$background = $this->hexRGB('ffffff');
			imagefill($this->img, 0, 0, imagecolorallocate($this->img, $background['red'], $background['green'], $background['blue']));
		}
		
		/**
		 * DrawStave
		 */
		public function DrawStave() {
			$line = $this->hexRGB('000000');
			
			// drawing lines
			for ($i = 0; $i<5; $i++) {
				$color = imagecolorallocate($this->img, $line['red'], $line['green'], $line['blue']);
				imageline($this->img, 0, $this->conf['linestart']+$i*$this->conf['linespace'], $this->conf['width'], $this->conf['linestart']+$i*$this->conf['linespace'], $color);
			}
		}
		
		/**
		 * DrawImage
		 */
		private function DrawImage($path, $x, $y) {
			$source = imagecreatefrompng($path);
			imagecopy($this->img, $source, $x, $y, 0, 0, imagesx($source), imagesy($source));
		}
		
		/**
		 * DrawKey
		 */
		public function DrawKey() {
			$path = $this->conf['imgpath'].'klic.png';
			$this->DrawImage($path, 5, 0);
		}
		
		/**
		 * DrawTime
		 */
		public function DrawTIme($type=4) {
			$path = $this->conf['imgpath'].'takt_'.$type.'.png';
			$this->DrawImage($path, 30, 12);
		}
		
		/**
		 * DrawNote
		 */
		public function DrawNote($x, $y, $type=0) {
			$path = $this->conf['imgpath'].'nota_'.$type.'.png';
			$this->DrawImage($path, $x, $y);
		}
		
		/**
		 * DrawBreak
		 */
		public function DrawBreak($x, $y, $type=0) {
			$path = $this->conf['imgpath'].'pomlka_'.$type.'.png';
			$this->DrawImage($path, $x, $y);
		}
		
		/**
		 * DrawBar
		 */
		public function DrawBar($x) {
			$line = $this->hexRGB('000000');
			$color = imagecolorallocate($this->img, $line['red'], $line['green'], $line['blue']);
			imageline($this->img, $x, $this->conf['linestart'], $x, $this->conf['linestart']+4*$this->conf['linespace'], $color);
		}
	};
?>